.. _examples :

=================
Examples
=================

The following scripts demonstrate several examples of using **WFacer** for practical
applications. You can simply view an example python script by clicking it's link.


Basic Examples
--------------

.. toctree::
   :maxdepth: 2

   example_scripts/semi_automation_BCC_AlLi/index
   example_scripts/full_automation_FCC_AgLi/index


More to come...
